==> antd-pro-toolkit-0.6.0.tgz: package/es/Uploader/File.js <==
import React from 'react';
import { Icon } from 'antd';
import Ellipsis from '../Ellipsis';
import './style';

var File = function File(props) {
  var item = props.item,
      handlePreview = props.handlePreview,
      _props$isUploading = props.isUploading,
      isUploading = _props$isUploading === void 0 ? true : _props$isUploading,
      handleRemove = props.handleRemove,
      width = props.width;
  var imgType = ['png', 'jpeg', 'jpg', 'pdf'];
  var fileType = item.name.split('.').reverse()[0].toLowerCase();
  var isImg = imgType.includes(fileType);
  var length = Math.floor((width - 100) / 14);
  return React.createElement("span", {
    className: 'uploadFile',
    onClick: function onClick() {
      return handlePreview(item);
    }
  }, React.createElement("div", {
    className: "ant-upload-list ant-upload-list-text"
  }, React.createElement("div", {
    className: "ant-upload-list-item ant-upload-list-item-done"
  }, React.createElement("div", {
    className: "ant-upload-list-item-info"
  }, React.createElement("span", {
    className: 'name'
  }, React.createElement(Icon, {
    style: {
      fontSize: 14
    },
    type: isImg ? 'file-image' : 'file'
  }), React.createElement("a", {
    className: 'name',
    style: {
      marginLeft: 20
    }
  }, React.createElement(Ellipsis, {
    tooltip: true,
    length: length
  }, item.name)))), isUploading ? React.createElement(Icon, {
    style: {
      fontSize: 14
    },
    type: "close",
    onClick: function onClick(e) {
      e.stopPropagation();
      handleRemove(item);
    }
  }) : React.createElement("div", null))));
};

export default File;

==> antd-pro-toolkit-0.6.8.tgz: package/es/Uploader/File.js <==
import React from 'react';
import Ellipsis from '../Ellipsis';
import { CloseOutlined, FileImageOutlined, FileOutlined } from '@ant-design/icons';
import './style';

var File = function File(props) {
  var item = props.item,
      handlePreview = props.handlePreview,
      _props$isUploading = props.isUploading,
      isUploading = _props$isUploading === void 0 ? true : _props$isUploading,
      handleRemove = props.handleRemove,
      width = props.width;
  var imgType = ['png', 'jpeg', 'jpg', 'pdf'];
  var fileType = item.name.split('.').reverse()[0].toLowerCase();
  var isImg = imgType.includes(fileType);
  var length = Math.floor((width - 100) / 14);
  return React.createElement("span", {
    className: 'uploadFile',
    onClick: function onClick() {
      return handlePreview(item);
    }
  }, React.createElement("div", {
    className: "ant-upload-list ant-upload-list-text"
  }, React.createElement("div", {
    className: "ant-upload-list-item ant-upload-list-item-done"
  }, React.createElement("div", {
    className: "ant-upload-list-item-info"
  }, React.createElement("span", {
    className: 'name'
  }, isImg ? React.createElement(FileImageOutlined, {
    style: {
      fontSize: 14
    }
  }) : React.createElement(FileOutlined, {
    style: {
      fontSize: 14
    }
  }), React.createElement("a", {
    className: 'name',
    style: {
      marginLeft: 20
    }
  }, React.createElement(Ellipsis, {
    tooltip: true,
    length: length
  }, item.name)))), isUploading ? React.createElement(CloseOutlined, {
    style: {
      fontSize: 14
    },
    onClick: function onClick(e) {
      e.stopPropagation();
      handleRemove(item);
    }
  }) : React.createElement("div", null))));
};

export default File;
